==> nnabla_rl-0.15.0-py3-none-any.whl: nnabla_rl/builders/lr_scheduler_builder.py <==

# Copyright 2023 Sony Group Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import nnabla as nn
from nnabla.utils.learning_rate_scheduler import BaseLearningRateScheduler
from nnabla_rl.algorithm import AlgorithmConfig
from nnabla_rl.environments.environment_info import EnvironmentInfo


class LearningRateSchedulerBuilder():
    """Learning rate scheduler builder interface class
    """

    def __call__(self,
                 env_info: EnvironmentInfo,
                 algorithm_config: AlgorithmConfig,
                 **kwargs) -> nn.solver.Solver:
        return self.build_scheduler(env_info, algorithm_config, **kwargs)

    def build_scheduler(self,
                        env_info: EnvironmentInfo,
                        algorithm_config: AlgorithmConfig,
                        **kwargs) -> BaseLearningRateScheduler:
        """Build learning rate scheduler function

        Args:
            env_info (:py:class:`EnvironmentInfo <nnabla_rl.environments.environment_info.EnvironmentInfo>`):\
                environment information
            algorithm_config (:py:class:`AlgorithmConfig <nnabla_rl.algorithm.AlgorithmConfig>`): \
                configuration class of the target algorithm

        Returns:
            BaseLearningRateScheduler: scheduler instance.
        """
        raise NotImplementedError

==> nnabla_rl-0.16.0-py3-none-any.whl: nnabla_rl/builders/lr_scheduler_builder.py <==
# Copyright 2023,2024 Sony Group Corporation.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import nnabla as nn
from nnabla.utils.learning_rate_scheduler import BaseLearningRateScheduler
from nnabla_rl.algorithm import AlgorithmConfig
from nnabla_rl.environments.environment_info import EnvironmentInfo


class LearningRateSchedulerBuilder:
    """Learning rate scheduler builder interface class"""

    def __call__(self, env_info: EnvironmentInfo, algorithm_config: AlgorithmConfig, **kwargs) -> nn.solver.Solver:
        return self.build_scheduler(env_info, algorithm_config, **kwargs)

    def build_scheduler(
        self, env_info: EnvironmentInfo, algorithm_config: AlgorithmConfig, **kwargs
    ) -> BaseLearningRateScheduler:
        """Build learning rate scheduler function

        Args:
            env_info (:py:class:`EnvironmentInfo <nnabla_rl.environments.environment_info.EnvironmentInfo>`):\
                environment information
            algorithm_config (:py:class:`AlgorithmConfig <nnabla_rl.algorithm.AlgorithmConfig>`): \
                configuration class of the target algorithm

        Returns:
            BaseLearningRateScheduler: scheduler instance.
        """
        raise NotImplementedError
